#include "DemoSelectorView.h"


/**
 * HELPER: getAdConfigForScreen
 *
 * this is just for this Demo-purpose, you should have
 * your own adConfig properly mainatined
 **/
static PCAdConfig* getAdConfigForScreen(std::string screenName)
{
    PCAdConfig* adConfig = new PCAdConfig();
    
    if (screenName.compare("DemoScreen1") == 0)
    {
        adConfig->screenName = "DemoScreen1";
        
        adConfig->defaultSkipTime = 5;
        adConfig->shouldAllowSkip = true;
        adConfig->shouldAllowMute = true;
        adConfig->shouldConfirmSkip = true;
        adConfig->skipConfirmMessage = "Do you want to skip the video?";
        adConfig->skipConfirmYesLabel = "Okay";
        adConfig->skipConfirmNoLabel = "Nope";
        adConfig->skipTimerMessage = "Must watch for ## seconds";
        adConfig->incentiveMessage = "more seconds to go!";
    }
    else
    {
        adConfig->screenName = "DemoScreen2";
        
        // keeping the rest as default
    }
    
    return adConfig;
}

static PCPokktConfig* config = new PCPokktConfig();
static DemoSelectorView* viewInstance = NULL;

bool DemoSelectorView::init()
{
    if (!BaseView::init())
        return false;
    
    backButton->setVisible(false);
    
    int yPos = logo->getPosition().y - logo->getBoundingBox().size.height / 2;
    
    // create buttons
    
    _btnInitPokkt = createButton("Init Pokkt First", CC_CALLBACK_1(DemoSelectorView::handleInitPokkt, this), "button_purple.png");
    _btnInitPokkt->setPosition(Vec2(visibleSize.width / 2, yPos));
    _btnInitPokkt->setScale(0.7f);
    this->addChild(_btnInitPokkt);
    
    yPos -= 120;
    
    _btnStartDemo1 = createButton("DemoScreen1", CC_CALLBACK_1(DemoSelectorView::handleStartDemo1, this));
    _btnStartDemo1->setPosition(Vec2(visibleSize.width / 2, yPos));
    this->addChild(_btnStartDemo1);
    
    yPos -= 100;
    
    _btnStartDemo2 = createButton("DemoScreen2", CC_CALLBACK_1(DemoSelectorView::handleStartDemo2, this));
    _btnStartDemo2->setPosition(Vec2(visibleSize.width / 2, yPos));
    this->addChild(_btnStartDemo2);
    
    yPos -= 100;
    
    _btnStartOfferwall = createButton("Start Offerwall", CC_CALLBACK_1(DemoSelectorView::handleStartOfferwall, this), "button_purple.png");
    _btnStartOfferwall->setPosition(Vec2(visibleSize.width / 2, yPos));
    this->addChild(_btnStartOfferwall);
    
    yPos -= 120;
    
    _btnExportLog = createButton("Export Log", CC_CALLBACK_1(DemoSelectorView::handleExportLog, this), "button_purple.png");
    _btnExportLog->setPosition(Vec2(visibleSize.width / 2, yPos));
    _btnExportLog->setScale(0.7f);
    this->addChild(_btnExportLog);
    
    // hide all buttons
    _btnStartDemo1->setVisible(false);
    _btnStartDemo2->setVisible(false);
    _btnStartOfferwall->setVisible(false);
    
    // listen
    PCPokktManager::setPokktInitializedListener(PC_POKKT_INITIALIZED_EVENT_SELECTOR(DemoSelectorView::handlePokktInitialized), this);
    
    // misc. pokkt flag setup
    PCPokktManager::setDebug(true);
    PCPokktManager::showLog("pokkt init...");
    
    return true;
}

DemoSelectorView::~DemoSelectorView()
{
    PCPokktManager::removePokktInitializedListener();
}

PCPokktConfig* DemoSelectorView::getPokktConfig()
{
    // SET THESE UP AS PER VALUES PROVIDED TO YOU
    
    // SampleApp(videodemo) credentials
    config->securityKey = "iJ02lJss0M";
    config->applicationId = "a2717a45b835b5e9f50284a38d62a74e";
    config->integrationType = POKKT_INTEGRATION_TYPE_ALL;
    config->thirdPartyUserId = "123456";
    
    return config;
}

DemoSelectorView* DemoSelectorView::getView()
{
    if (viewInstance == NULL)
    {
        viewInstance = DemoSelectorView::create();
        viewInstance->retain();
    }
    return viewInstance;
}

void DemoSelectorView::handleBackPress(cocos2d::Ref *pSender)
{
    // exit the app
    Director::getInstance()->end();
}

void DemoSelectorView::handleInitPokkt(cocos2d::Ref* pSender)
{
    PCPokktManager::initPokkt(getPokktConfig());
    _btnInitPokkt->setTitleText("initializing...");
    _btnInitPokkt->setEnabled(false);
}

void DemoSelectorView::handleStartDemo1(cocos2d::Ref* pSender)
{
    ChangeViewParams params;
    params.viewToChange = AdDemoView;
    params.adConfig = getAdConfigForScreen("DemoScreen1");
    changeView(params);
}

void DemoSelectorView::handleStartDemo2(cocos2d::Ref* pSender)
{
    ChangeViewParams params;
    params.viewToChange = AdDemoView;
    params.adConfig = getAdConfigForScreen("DemoScreen2");
    changeView(params);
}

void DemoSelectorView::handleStartOfferwall(cocos2d::Ref* pSender)
{
    ChangeViewParams params;
    params.viewToChange = OfferwallView;
    changeView(params);
}

void DemoSelectorView::handleExportLog(cocos2d::Ref* pSender)
{
    PCPokktManager::exportLog();
}

void DemoSelectorView::handlePokktInitialized(bool isReady)
{
    _btnInitPokkt->setEnabled(!isReady);
    _btnStartDemo1->setVisible(isReady);
    _btnStartDemo2->setVisible(isReady);
    _btnStartOfferwall->setVisible(isReady);
    
    if (isReady)
        _btnInitPokkt->setTitleText("pokkt initialised!");
}
